<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="et">
<context>
    <name>About</name>
    <message>
        <location filename="../about.ui" line="14"/>
        <source>About...</source>
        <translation>Info...</translation>
    </message>
    <message>
        <location filename="../about.ui" line="33"/>
        <source>&amp;Info</source>
        <translation>&amp;Info</translation>
    </message>
    <message>
        <location filename="../about.ui" line="53"/>
        <location filename="../about.ui" line="109"/>
        <location filename="../about.ui" line="165"/>
        <source>icon</source>
        <translation>Ikoon</translation>
    </message>
    <message>
        <location filename="../about.ui" line="89"/>
        <source>&amp;Translators</source>
        <translation>&amp;Tõlkijad</translation>
    </message>
    <message>
        <location filename="../about.ui" line="145"/>
        <source>&amp;License</source>
        <translation>&amp;Litsents</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="33"/>
        <source>YouTube%1 Browser for SMPlayer</source>
        <translation>Youtube%1 lehitseja SMPlayerile</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="35"/>
        <source>Based on UMPlayer</source>
        <translation>Valmistatud UMPlayeri põhjal</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="37"/>
        <source>Version: %1</source>
        <translation>Versioon: %1</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="39"/>
        <source>Portable Edition</source>
        <translation>Kaasaskantav väljaanne</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="42"/>
        <source>Compiled with Qt %1 (using %2)</source>
        <translation>Valmistatud Qt-ga %1 (kasutab %2)</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="44"/>
        <source>Visit our web for updates:</source>
        <translation>Uuenduste hankimiseks külastage meie kodulehekülge:</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="98"/>
        <source>Spanish</source>
        <translation>Hispaania</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="115"/>
        <source>Russian</source>
        <translation>Vene</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="108"/>
        <source>Lithuanian</source>
        <translation>Leedu</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="102"/>
        <source>Japanese</source>
        <translation>Jaapani</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="99"/>
        <source>Basque</source>
        <translation>Baski</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="104"/>
        <source>Portuguese</source>
        <translation>Portugali</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="119"/>
        <source>Hungarian</source>
        <translation>Ungari</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="114"/>
        <source>Polish</source>
        <translation>Poola</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="111"/>
        <source>Hebrew</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../about.cpp" line="106"/>
        <source>Ukrainian</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../about.cpp" line="125"/>
        <source>Norwegian Nynorsk</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../about.cpp" line="101"/>
        <source>Czech</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../about.cpp" line="92"/>
        <source>Many people contributed with translations.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../about.cpp" line="93"/>
        <source>You can also help to translate SMPlayer into your own language.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../about.cpp" line="94"/>
        <source>Visit %1 and join a translation team.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../about.cpp" line="96"/>
        <source>Current translators from the transifex teams:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../about.cpp" line="103"/>
        <source>Korean</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../about.cpp" line="109"/>
        <source>Malay</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../about.cpp" line="110"/>
        <source>Portuguese - Brazil</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../about.cpp" line="112"/>
        <source>Simplified Chinese</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../about.cpp" line="116"/>
        <source>French</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../about.cpp" line="118"/>
        <source>Danish</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../about.cpp" line="122"/>
        <source>German</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../about.cpp" line="123"/>
        <source>Traditional Chinese</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../about.cpp" line="126"/>
        <source>Swedish</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../about.cpp" line="120"/>
        <source>Turkish</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../about.cpp" line="121"/>
        <source>Finnish</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../about.cpp" line="127"/>
        <source>Arabic</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../about.cpp" line="128"/>
        <source>Georgian</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../about.cpp" line="105"/>
        <source>Serbian</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../about.cpp" line="100"/>
        <source>Croatian</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../about.cpp" line="124"/>
        <source>Bulgarian</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../about.cpp" line="113"/>
        <source>Vietnamese</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../about.cpp" line="117"/>
        <source>Indonesian</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../about.cpp" line="129"/>
        <source>Arabic - Saudi Arabia</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../about.cpp" line="130"/>
        <source>Sinhala</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../about.cpp" line="131"/>
        <source>Greek</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../about.cpp" line="132"/>
        <source>Estonian</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../about.cpp" line="133"/>
        <source>N&apos;ko</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../about.cpp" line="134"/>
        <source>Italian</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../about.cpp" line="135"/>
        <source>Uzbek</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../about.cpp" line="136"/>
        <source>Catalan</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../about.cpp" line="137"/>
        <source>Slovak</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../about.cpp" line="138"/>
        <source>British English</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../about.cpp" line="139"/>
        <source>Albanian</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../about.cpp" line="140"/>
        <source>Dutch</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../about.cpp" line="141"/>
        <source>Romanian</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../about.cpp" line="142"/>
        <source>Khmer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../about.cpp" line="143"/>
        <source>Telugu</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../about.cpp" line="144"/>
        <source>Tamil</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../about.cpp" line="145"/>
        <source>Malayalam</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../about.cpp" line="170"/>
        <source>&lt;b&gt;%1&lt;/b&gt; (%2)</source>
        <translation>&lt;b&gt;%1&lt;/b&gt; (%2)</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="107"/>
        <source>Galician</source>
        <translation>Galeegi</translation>
    </message>
</context>
<context>
    <name>CodeDownloader</name>
    <message>
        <location filename="../codedownloader.cpp" line="37"/>
        <source>Downloading...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="58"/>
        <source>Connecting to %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="126"/>
        <source>The Youtube code has been updated successfully.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="127"/>
        <source>Installed version: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="128"/>
        <source>Success</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="133"/>
        <location filename="../codedownloader.cpp" line="138"/>
        <source>Error</source>
        <translation type="unfinished">Viga</translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="133"/>
        <source>An error happened writing %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="138"/>
        <source>An error happened while downloading the file:&lt;br&gt;%1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ConfigDialog</name>
    <message>
        <location filename="../configdialog.ui" line="14"/>
        <source>Settings</source>
        <translation>Seaded</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="20"/>
        <source>Recording</source>
        <translation>Salvestamine</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="28"/>
        <source>&amp;Save to this folder</source>
        <translation>&amp;Salvestage sellesse kausta</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="45"/>
        <source>&amp;Quality</source>
        <translation>&amp;Kvaliteet</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="157"/>
        <source>Standard Feeds</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="163"/>
        <source>&amp;Region:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="189"/>
        <source>Period of &amp;time:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="80"/>
        <source>Playback</source>
        <translation>Taasesitus</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="88"/>
        <source>Q&amp;uality:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="125"/>
        <source>&amp;Player:</source>
        <translation>&amp;Esitaja:</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="40"/>
        <source>All time</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="41"/>
        <source>This month</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="42"/>
        <source>This week</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="43"/>
        <source>Today</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DownloadFile</name>
    <message>
        <location filename="../downloadfile.cpp" line="117"/>
        <source>%1 hours</source>
        <translation>%1 tundi</translation>
    </message>
    <message>
        <location filename="../downloadfile.cpp" line="123"/>
        <source>%1 minutes</source>
        <translation>%1 minutit</translation>
    </message>
    <message>
        <location filename="../downloadfile.cpp" line="110"/>
        <source>unknown time remaining</source>
        <translation>teadmatu olek</translation>
    </message>
    <message>
        <location filename="../downloadfile.cpp" line="126"/>
        <source>%1 seconds</source>
        <translation>%1 sekundit</translation>
    </message>
    <message>
        <location filename="../downloadfile.cpp" line="127"/>
        <source>%1 remaining</source>
        <translation>Aega jäänud %1</translation>
    </message>
    <message>
        <location filename="../downloadfile.cpp" line="132"/>
        <source>%1 of %2 MB</source>
        <translation>%1 %2 MB-st</translation>
    </message>
    <message>
        <location filename="../downloadfile.cpp" line="138"/>
        <source>%1 of %2 KB</source>
        <translation>%1 %2 KB-st</translation>
    </message>
    <message>
        <location filename="../downloadfile.cpp" line="144"/>
        <source>%1 of %2 bytes</source>
        <translation>%1 %2 baidist</translation>
    </message>
    <message>
        <location filename="../downloadfile.cpp" line="148"/>
        <source>%1 of unknown size</source>
        <translation>%1 tundmatusest suurusest</translation>
    </message>
    <message>
        <location filename="../downloadfile.cpp" line="153"/>
        <source>%1 MB/sec</source>
        <translation>%1 MB/sek</translation>
    </message>
    <message>
        <location filename="../downloadfile.cpp" line="157"/>
        <source>%1 KB/sec</source>
        <translation>%1 KB/sek</translation>
    </message>
    <message>
        <location filename="../downloadfile.cpp" line="161"/>
        <source>%1 bytes/sec</source>
        <translation>%1 baiti/sek</translation>
    </message>
</context>
<context>
    <name>FileChooser</name>
    <message>
        <location filename="../filechooser.cpp" line="54"/>
        <source>Click to select a file or folder</source>
        <translation>Faili või kausta valimiseks vajutage</translation>
    </message>
</context>
<context>
    <name>RecordingDelegate</name>
    <message>
        <location filename="../recordingdialog.cpp" line="125"/>
        <source>Canceled</source>
        <translation>Peatatud</translation>
    </message>
    <message>
        <location filename="../recordingdialog.cpp" line="125"/>
        <source>Error</source>
        <translation>Viga</translation>
    </message>
    <message>
        <location filename="../recordingdialog.cpp" line="155"/>
        <source>%1 MB</source>
        <translation>%1 MB</translation>
    </message>
    <message>
        <location filename="../recordingdialog.cpp" line="159"/>
        <source>%1 KB</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../recordingdialog.cpp" line="163"/>
        <source>%1 bytes</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RecordingDialog</name>
    <message>
        <location filename="../recordingdialog.cpp" line="208"/>
        <location filename="../recordingdialog.cpp" line="527"/>
        <source>Recordings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../recordingdialog.cpp" line="209"/>
        <source>&amp;Clear list</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../recordingdialog.cpp" line="210"/>
        <location filename="../recordingdialog.cpp" line="658"/>
        <source>&amp;Open folder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../recordingdialog.cpp" line="345"/>
        <location filename="../recordingdialog.cpp" line="357"/>
        <location filename="../recordingdialog.cpp" line="777"/>
        <source>There was an error in retrieving the download URL.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../recordingdialog.cpp" line="345"/>
        <location filename="../recordingdialog.cpp" line="357"/>
        <location filename="../recordingdialog.cpp" line="777"/>
        <source>Recording failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../recordingdialog.cpp" line="413"/>
        <location filename="../recordingdialog.cpp" line="795"/>
        <source>Starting</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../recordingdialog.cpp" line="448"/>
        <source>Error</source>
        <translation type="unfinished">Viga</translation>
    </message>
    <message>
        <location filename="../recordingdialog.cpp" line="452"/>
        <source>Completed</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <location filename="../recordingdialog.cpp" line="531"/>
        <source>%1% of %n video - Recordings</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <location filename="../recordingdialog.cpp" line="616"/>
        <source>&amp;Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../recordingdialog.cpp" line="618"/>
        <source>&amp;Remove from list</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../recordingdialog.cpp" line="639"/>
        <location filename="../recordingdialog.cpp" line="661"/>
        <source>Remove from &amp;list</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../recordingdialog.cpp" line="635"/>
        <source>&amp;Retry</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../recordingdialog.cpp" line="657"/>
        <source>&amp;Play</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../recordingdialog.cpp" line="660"/>
        <source>&amp;Delete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../recordingdialog.cpp" line="742"/>
        <source>Fetching URL...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../recordingdialog.cpp" line="759"/>
        <source>File error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../recordingdialog.cpp" line="760"/>
        <source>The file does not exists, would you like to remove it from the list?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Regions</name>
    <message>
        <location filename="../regions.cpp" line="26"/>
        <source>Argentina</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="27"/>
        <source>Australia</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="29"/>
        <source>Belgium</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="30"/>
        <source>Brazil</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="31"/>
        <source>Canada</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="32"/>
        <source>Chile</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="33"/>
        <source>Colombia</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="34"/>
        <source>Czech Republic</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="35"/>
        <source>Egypt</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="36"/>
        <source>France</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="37"/>
        <source>Germany</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="38"/>
        <source>Great Britain</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="39"/>
        <source>Hong Kong</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="40"/>
        <source>Hungary</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="41"/>
        <source>India</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="42"/>
        <source>Ireland</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="43"/>
        <source>Israel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="44"/>
        <source>Italy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="45"/>
        <source>Japan</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="46"/>
        <source>Jordan</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="47"/>
        <source>Malaysia</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="48"/>
        <source>Mexico</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="49"/>
        <source>Morocco</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="50"/>
        <source>Netherlands</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="51"/>
        <source>New Zealand</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="52"/>
        <source>Peru</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="53"/>
        <source>Philippines</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="54"/>
        <source>Poland</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="55"/>
        <source>Russia</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="56"/>
        <source>Saudi Arabia</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="57"/>
        <source>Singapore</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="58"/>
        <source>South Africa</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="59"/>
        <source>South Korea</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="60"/>
        <source>Spain</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="61"/>
        <source>Sweden</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="63"/>
        <source>Taiwan</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="64"/>
        <source>United Arab Emirates</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="65"/>
        <source>United States</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>YTDelegate</name>
    <message>
        <location filename="../ytdelegate.cpp" line="115"/>
        <source>%L1 views</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>YTDialog</name>
    <message>
        <location filename="../ytdialog.cpp" line="227"/>
        <source>YouTube Browser - SMPlayer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ytdialog.cpp" line="277"/>
        <source>Settings</source>
        <translation type="unfinished">Seaded</translation>
    </message>
    <message>
        <location filename="../ytdialog.cpp" line="283"/>
        <source>Information</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ytdialog.cpp" line="290"/>
        <source>Show recordings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ytdialog.cpp" line="296"/>
        <source>Enter URL</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ytdialog.cpp" line="497"/>
        <source>Most Relevant</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ytdialog.cpp" line="501"/>
        <source>Most Recent</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ytdialog.cpp" line="505"/>
        <source>Most Viewed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ytdialog.cpp" line="509"/>
        <source>Most Popular</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ytdialog.cpp" line="535"/>
        <source>Most popular videos on YouTube%1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ytdialog.cpp" line="656"/>
        <source>Error: Could not connect to Youtube server.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ytdialog.cpp" line="766"/>
        <source>R&amp;ecord audio</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ytdialog.cpp" line="771"/>
        <source>&amp;Add URL to the SMPlayer playlist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ytdialog.cpp" line="839"/>
        <source>Enter a URL</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ytdialog.cpp" line="963"/>
        <location filename="../ytdialog.cpp" line="974"/>
        <source>Problems with Youtube</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ytdialog.cpp" line="965"/>
        <source>Do you want to update the Youtube code? This may fix the problem.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ytdialog.cpp" line="964"/>
        <location filename="../ytdialog.cpp" line="975"/>
        <source>Unfortunately due to changes in Youtube, the video &apos;%1&apos; can&apos;t be played or recorded.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ytdialog.cpp" line="976"/>
        <source>Maybe updating this application could fix the problem.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ytdialog.cpp" line="540"/>
        <source>YouTube%2 results for &quot;%1&quot;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ytdialog.cpp" line="513"/>
        <source>Music</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ytdialog.cpp" line="517"/>
        <source>Sports</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ytdialog.cpp" line="536"/>
        <source>Most popular sport videos on YouTube%1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ytdialog.cpp" line="537"/>
        <source>Most popular music videos on YouTube%1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ytdialog.cpp" line="664"/>
        <source>No videos found</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ytdialog.cpp" line="666"/>
        <source>No videos found for &quot;%1&quot;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ytdialog.cpp" line="763"/>
        <source>&amp;Play video</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ytdialog.cpp" line="765"/>
        <source>&amp;Record video</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ytdialog.cpp" line="768"/>
        <source>&amp;Watch on YouTube</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ytdialog.cpp" line="769"/>
        <source>&amp;Copy link</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ytdialog.cpp" line="252"/>
        <source>Next</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ytdialog.cpp" line="258"/>
        <source>Previous</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ytdialog.cpp" line="840"/>
        <source>Enter a Youtube URL to record</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ytdialog.cpp" line="949"/>
        <location filename="../ytdialog.cpp" line="951"/>
        <source>Error</source>
        <translation type="unfinished">Viga</translation>
    </message>
</context>
</TS>
